@@ -87,6 +87,16 @@ class CloneDBInstanceRequest(RpcRequest):
 
 	def set_InstanceNetworkType(self, InstanceNetworkType):  # String
 		self.add_query_param('InstanceNetworkType', InstanceNetworkType)
+	def get_ZoneIdSlave1(self): # String
+		return self.get_query_params().get('ZoneIdSlave1')
+
+	def set_ZoneIdSlave1(self, ZoneIdSlave1):  # String
+		self.add_query_param('ZoneIdSlave1', ZoneIdSlave1)
+	def get_ZoneIdSlave2(self): # String
+		return self.get_query_params().get('ZoneIdSlave2')
+
+	def set_ZoneIdSlave2(self, ZoneIdSlave2):  # String
+		self.add_query_param('ZoneIdSlave2', ZoneIdSlave2)
 	def get_TableMeta(self): # String
 		return self.get_query_params().get('TableMeta')
 
